Inspired by Ruby’s ARGF.
Treat files and stdin as if they were a big long concatenated stream.
argf() will pull input from your command line arguments,
no frills, no questions asked, and argf_lines() will
give you an iterator over all lines of command line input.
argf() and argf_lines() assume that the command line arguments contain only
file arguments. If you need a little more control (for example, you’re using docopt
to parse command line arguments instead), use input() or
input_lines()
Structs
Functions
- argf
- Act like
input(), but automatically pull arguments from the command line. - argf_
lines - Act like
input_lines(), but automatically pull arguments from the command line. - input
- Return a
Readinstance with all the input files/stdinchained together. - input_
lines - Return an iterator over all lines of input.